pub(crate) struct Stats {
pub(crate) files_matched: i32,
pub(crate) commands_run: i32,
pub(crate) commands_failed: i32,
}Expand description
Execution statistics printed in the summary line.
Tracks how many files matched, how many commands were executed (or would have been in dry-run mode), and how many commands returned a non-zero exit code. The summary is printed to stderr at the end of execution when verbose, dry-run, or any command has failed.
Fields
files_matched: i32Number of directory entries that matched the regex and all metadata filters.
commands_run: i32Number of commands executed (or printed in dry-run mode).
commands_failed: i32Number of commands that returned a non-zero exit status.